import {gql} from '../helpers'
import {   
   actionPromise, 
   actionAddListInChats,
   actionAddChatInChats, 
   actionUpdateChatInChats,
   actionRemoveChatInChats,
} from '../reducers'



export const actionAddChat = (title) => (
   actionPromise('addChat', gql(`mutation addChat($chat:ChatInput) {
      ChatUpsert(chat:$chat) {
         _id     
         owner {_id login}       
         title
         members {
            _id
            login
         }      
      }
   }`, { chat: { title } }
   ))
)

// в массив newMemders передавать объекты только с полем _id
export const actionUpdateChat = (chatId, newTitle, newMemders) => (
   actionPromise('updateChat', gql(`mutation updateChat($chat:ChatInput) {
      ChatUpsert(chat:$chat) {
         _id     
         owner {_id login}       
         title
         members {
            _id
            login
         }      
      }
   }`, { chat: {_id: chatId, title: newTitle, members: newMemders} }))
)

// не работает
// export const actionRemoveChat = (chatId) => (
//    actionPromise('removeChat', gql(`mutation removeChat($chat:ChatInput) {
//       ChatDelete(chat:$chat) {
//          _id     
//       }
//    }`, { chat: {_id: chatId} }))
// )


// поиск по значению в массиве объектов - { 'members._id': userId }
export const actionGetChatsByUser = (userId, skipCount=0, limitCount=50) => (
   actionPromise('userChats', gql(`query userChats($q: String) {
      ChatFind (query: $q){
         _id
         title
         avatar {
            url
         }
         owner {
            login
         }
         members {
            _id
            login
         }
            messages {
               _id
               owner {
                  login
               }
               text
            }
         lastModified
      }     
   }`, { 
         q: JSON.stringify([  {
                                $or: [
                                       { ___owner: userId }, 
                                       { 'members._id': userId }
                                    ]  
                              },
                              { 
                                 sort: [{lastModified: -1}],  
                                 skip: [skipCount], 
                                 limit: [limitCount] 
                              } 
                           ])
      }
   ))
)




export const actionFullChatList = (userId, currentCount, limitCount=50) => (
   async (dispatch) => {
      let payload = await dispatch(actionGetChatsByUser(userId, currentCount, limitCount))
      if (payload) {
         dispatch(actionAddListInChats(payload))
      }
   }
)

















// вспомогательный запрос
export const actionGetAllChats = (userId) => (
   actionPromise('getAll', gql(`query getAll($q: String){
      ChatFind (query: $q){
         _id
         title
         owner {
            login
         }
         avatar {
            url
         }
         members {
            _id
            login
         }
         messages {
            owner {
               login
            }
            text
         }
         lastModified
      }         
   }`, { 
         q: JSON.stringify([ { 'members._id': userId }, { skip: [0], limit: [100] } ])
         }
   ))
)