import {gql} from '../helpers'
import {   
   actionPromise,
   actionMsgListInChat, 
   actionAddMsgInChat,
   actionUpdateMsgInChat,
} from '../reducers'
import {   
   actionUploadFile
} from './mediaActions'



export const actionGetMsgsByChat = (chatId, skipCount=0, limitCount=50) => (
   actionPromise('chatMsgs', gql(`query chatMsgs($q: String) {
      MessageFind (query: $q){
         _id
         createdAt
         owner {
            _id
            login
         }
         text

         media {
            url
         }
         forwardWith {
            _id
         }
         replies {
            _id
         }

         replyTo {
            _id
         }
         forwarded {
            _id
         }
      }     
   }`, { 
         q: JSON.stringify([  { "chat. _id": chatId },
                              { 
                                 sort: [{_id: -1}],  
                                 skip: [skipCount], 
                                 limit: [limitCount] 
                              } 
                           ])
      }
   ))
)


export const actionMsgsCount = (chatId) => (
   actionPromise('msgsCount', gql(`query msgsCount($q: String) {
      MessageCount (query: $q)  
   }`, { 
         q: JSON.stringify([ { chat: { _id: chatId } } ])
      }
   ))
)




export const actionAddMsg = (text) => (
   actionPromise('addMsg', gql(`mutation addMsg($msg: MessageInput) {
      MessageUpsert(message: $msg) {
         _id
         createdAt
         owner {
            _id
            login
         }
         text

         media {
            url
         }
         forwardWith {
            _id
         }
         replies {
            _id
         }

         replyTo {
            _id
         }
         forwarded {
            _id
         }
      }
   }`, { msg: { text } }
   ))
)

export const actionUpdateMsg = (msgId, text) => (
   actionPromise('updateMsg', gql(`mutation updateMsg($msg: MessageInput) {
      MessageUpsert(message: $msg) {
         _id
         createdAt
         owner {
            _id
            login
         }
         text

         media {
            url
         }
         forwardWith {
            _id
         }
         replies {
            _id
         }

         replyTo {
            _id
         }
         forwarded {
            _id
         }
      }
   }`, { msg: { _id: msgId, text } }
   ))
)

export const actionRemoveMsg = (msgId) => (
   actionPromise('removeMsg', gql(`mutation removeMsg($msg: MessageInput) {
      MessageDelete(message: $msg) {
         _id 
      }
   }`, { msg: { _id: msgId } }
   ))
)









   
      // !!!! ПОДХОД ВЕРНЫЙ ТОЛЬКО ДЛЯ ЗАГРУЗКИ МНОГИХ ФАЙЛОВ В СООБЩЕНИЕ - перенести в сообщения
   // позволяет загрузить файл и взамен получить url  
   // нужен для предпросмотра, когда юзер еще не определился нужно ли добавлять этот url в стейт
   export const actionGroupFiles = (name, file) => (
      async (dispatch, getState) => {
         let fileObj = await dispatch(actionUploadFile(name, file))
         let URL = fileObj.avatar.url
         console.log(fileObj._id)
         let {auth} = getState()
         let userId = auth.payload?.sub?.id  
      }
   )


