import React, {useState} from 'react'
import IconButton from '@mui/material/IconButton';
import MenuIcon from '@mui/icons-material/Menu';
import Menu from '@mui/material/Menu';
import MenuItem from '@mui/material/MenuItem';


import Drawer from '@mui/material/Drawer';
import Box from '@mui/material/Box';
import List from '@mui/material/List';
import Divider from '@mui/material/Divider';
import ListItem from '@mui/material/ListItem';
import ListItemText from '@mui/material/ListItemText';

import {actionAuthLogout} from "../reducers"
import {connect}  from 'react-redux';

import {CProfileModal, CUserAvatar} from '../components'


const LogoutBtn = ({onLogout}) => (
   <>
      <ListItem button onClick={onLogout} >
         <ListItemText primary={'Выйти'} />
      </ListItem>
   </>
)
const CLogoutBtn = connect(null, {onLogout: actionAuthLogout})(LogoutBtn)

export const MainMenu = () => {
   const [anchorEl, setAnchorEl] = useState(null)
   const open = !!anchorEl

   const handleClick = (event) => {
     setAnchorEl(event.currentTarget)
   }

   const handleClose = () => {
     setAnchorEl(null)
   }

   return (
      <>
         <IconButton edge="start" color="inherit" aria-label="menu" sx={{ mr: 2 }}
            id="basic-button"
            aria-controls={open ? 'basic-menu' : undefined}
            aria-haspopup="true"
            aria-expanded={open ? 'true' : undefined}
            onClick={handleClick}
         >
            <MenuIcon />
         </IconButton>
   
         <Menu
         id="basic-menu"
         anchorEl={anchorEl}
         open={open}
         onClose={handleClose}
         MenuListProps={{
         'aria-labelledby': 'basic-button',
         }}
         >

            <CProfileModal />

            <MenuItem onClick={handleClose}>
               Контакты
            </MenuItem>

            <CLogoutBtn />
                                    
         </Menu>
      </>
   ) 
}



export const MenuDrawer = ({}) => {
   const [state, setState] = useState(false);
   const open = !!state

 
   const toggleDrawer = (open) => (event) => {
     if ( event.type === 'keydown' && 
          ( event.key === 'Tab' || 
            event.key === 'Shift')) {
       return
     } 
     setState(open)
   } 

   return (
     <div>
         <IconButton edge="start" color="inherit" aria-label="menu" sx={{ mr: 1 }}
            id="basic-button"
            aria-controls={open ? 'basic-menu' : undefined}
            aria-haspopup="true"
            aria-expanded={open ? 'true' : undefined}
            onClick={toggleDrawer(true)}
         >
            
            <MenuIcon />
            <CUserAvatar sx={{ ml: 1}} />
         </IconButton>
         


         <Drawer
            open={state}
            onClose={toggleDrawer(false)}
         >

            <Box
            sx={{ width: 250 }}
            role="presentation"
            >
               <Box sx={{ m: 2, display: 'flex', justifyContent: 'center' }}>
                  <CUserAvatar bigSize={true} />
               </Box>               

               <List>
                  <CProfileModal />

                  <ListItem button >
                     <ListItemText primary={'Контакты'} />
                  </ListItem>

                  <Divider />

                  <CLogoutBtn />

               </List>
            </Box>

         </Drawer>
     </div>
   );
 }