import * as React from 'react';
import {useState, useEffect} from 'react';

import Avatar from '@mui/material/Avatar';
import Button from '@mui/material/Button';
import CssBaseline from '@mui/material/CssBaseline';
import TextField from '@mui/material/TextField';
import Link from '@mui/material/Link';
import Grid from '@mui/material/Grid';
import Box from '@mui/material/Box';
import LockOutlinedIcon from '@mui/icons-material/LockOutlined';
import Typography from '@mui/material/Typography';
import Container from '@mui/material/Container';
import { createTheme, ThemeProvider } from '@mui/material/styles';
// import FormControlLabel from '@mui/material/FormControlLabel';
// import Checkbox from '@mui/material/Checkbox';

import { actionFullLogin } from "../actions";
import { printStrReq } from "../helpers";
import {connect}  from 'react-redux';


const LoginForm = ({minLog='2', minPass='2', onLogin, logError}) => {
   const [login, setLogin] = useState('')
   const [logBlur, setLogBlur] = useState(false)

   const [pass, setPass] = useState('')
   const [passBlur, setPassBlur] = useState(false)
   
   const [wrongAlert, setWrongAlert] = useState(false)

   useEffect(() => {
      if (logError?.status === 'REJECTED') {
         delete localStorage.authToken
         onLogin(login, pass)
      } else if (logError?.payload === null) {
         setWrongAlert(true)
      } else {
         setWrongAlert(false)
      }
   },[logError])

   const handleSubmit = (event) => {
      event.preventDefault()
      onLogin(login, pass)
   }

   return (
      <Box component="form" onSubmit={handleSubmit} noValidate sx={{ mt: 1 }}>

         <TextField
            onChange={(e) => {
                  e.target.value = e.target.value.trim()
                  setLogin(e.target.value)
               }
            }     
            onBlur={() => {
                  setLogBlur(true)              
               }
            } 
            onFocus={() => {
                  setLogBlur(false)              
               }
            }          
            error={logBlur ? ((login.length >= minLog ) ? false : true) : false}
            helperText={printStrReq(login, minLog)}            

            inputProps={{
               maxLength: 25
            }}
            margin="normal"
            required
            fullWidth
            id="loginLog"
            label="Логин"
            name="login"
            autoComplete="login"
            autoFocus
         />

         <TextField
            onChange={(e) => {
                  e.target.value = e.target.value.trim()
                  setPass(e.target.value.trim())
               }
            }  
            onBlur={() => {
                  setPassBlur(true)              
               }
            } 
            onFocus={() => {
                  setPassBlur(false)              
               }
            }
            error={passBlur ? ((pass.length >= minPass ) ? false : true) : false}               
            helperText={printStrReq(pass, minPass)}            

            inputProps={{
               maxLength: 100
            }}
            margin="normal"
            required
            fullWidth
            name="password"
            label="Пароль"
            type="password"
            id="passwordLog"
            autoComplete="current-password"
         />
            {  wrongAlert ?  
                  <Typography component="p" variant="body2" mt={1} ml={2} 
                           sx={{fontWeight: 'medium', fontSize: '0.75rem', color: '#d32f2f'}}>
                              Неверный логин/пароль
                  </Typography> :
                  <></>
               }


         {/* данный компонент можно использовать вместе с 
         динамической записью в локалСторэйдж. как? */}
         {/* <FormControlLabel
            control={<Checkbox value="remember" color="primary" />}
            label="Запомнить меня"
         /> */}
         <Button
            disabled={(pass.length >= minPass && login.length >= minLog) ? false : true}

            type="submit"
            fullWidth
            variant="contained"
            sx={{ mt: 2, mb: 2 }}
         >
            Войти
         </Button>

         <Grid container justifyContent="flex-end">
            <Grid item>
               <Link href="/reg" variant="body2">
                  Нет аккаунта? Зарегистрируйтесь
               </Link>
            </Grid>
         </Grid>

      </Box>
   )
}
const CLoginForm = connect( (state) => ({logError: state.promise.login}), {onLogin: actionFullLogin})(LoginForm)


const theme = createTheme()
// аргументы - string
export const Login = ({minLog='2', minPass='2'}) => {

   return (
      <ThemeProvider theme={theme}>

      <Container component="main" maxWidth="xs">
         <CssBaseline />

         <Box
            sx={{
               marginTop: 8,
               display: 'flex',
               flexDirection: 'column',
               alignItems: 'center',
               justifyContent: 'center'
            }}
         >
            <Avatar sx={{ m: 1, bgcolor: 'secondary.main' }}>
               <LockOutlinedIcon />
            </Avatar>

            <Typography component="h1" variant="h5">
               Вход в аккаунт
            </Typography>

            <CLoginForm minLog={minLog} minPass={minPass} />

         </Box>
      </Container>
      </ThemeProvider>
   )
}


